import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_apigateway._jsii
import aws_cdk.aws_certificatemanager._jsii
import aws_cdk.aws_cloudfront._jsii
import aws_cdk.aws_cloudfront_origins._jsii
import aws_cdk.aws_cloudwatch._jsii
import aws_cdk.aws_cognito._jsii
import aws_cdk.aws_dynamodb._jsii
import aws_cdk.aws_ec2._jsii
import aws_cdk.aws_elasticloadbalancingv2._jsii
import aws_cdk.aws_elasticloadbalancingv2_targets._jsii
import aws_cdk.aws_elasticsearch._jsii
import aws_cdk.aws_events._jsii
import aws_cdk.aws_glue._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_iot._jsii
import aws_cdk.aws_kinesis._jsii
import aws_cdk.aws_kinesisanalytics._jsii
import aws_cdk.aws_kinesisfirehose._jsii
import aws_cdk.aws_kms._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.aws_lambda_event_sources._jsii
import aws_cdk.aws_logs._jsii
import aws_cdk.aws_mediastore._jsii
import aws_cdk.aws_s3._jsii
import aws_cdk.aws_s3_assets._jsii
import aws_cdk.aws_s3_notifications._jsii
import aws_cdk.aws_sagemaker._jsii
import aws_cdk.aws_secretsmanager._jsii
import aws_cdk.aws_sns._jsii
import aws_cdk.aws_sqs._jsii
import aws_cdk.aws_ssm._jsii
import aws_cdk.aws_stepfunctions._jsii
import aws_cdk.aws_wafv2._jsii
import aws_cdk.core._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-solutions-constructs/core",
    "1.132.0",
    __name__[0:-6],
    "core@1.132.0.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
